==> haskell-attoparsec-iso8601-1.0.1.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.1.0
id: attoparsec-iso8601-1.0.1.0-EUzz1BrQBjF9AF4vR04oW
key: attoparsec-iso8601-1.0.1.0-EUzz1BrQBjF9AF4vR04oW
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
abi: cc587fb94b211db63d7a952664cd998a
exposed: True
exposed-modules:
    Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/attoparsec-iso8601-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/attoparsec-iso8601-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/attoparsec-iso8601-1.0.1.0
hs-libraries: HSattoparsec-iso8601-1.0.1.0-EUzz1BrQBjF9AF4vR04oW
depends:
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr text-1.2.3.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.0.1.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.1.0
id: attoparsec-iso8601-1.0.1.0-H6kRr6PRuNJAFxxyoNfeHx
key: attoparsec-iso8601-1.0.1.0-H6kRr6PRuNJAFxxyoNfeHx
license: BSD-3-Clause
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
abi: 847f398f299b87b545e4e5cff3573f8b
exposed: True
exposed-modules:
    Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/attoparsec-iso8601-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/attoparsec-iso8601-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/attoparsec-iso8601-1.0.1.0
hs-libraries: HSattoparsec-iso8601-1.0.1.0-H6kRr6PRuNJAFxxyoNfeHx
depends:
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr text-1.2.3.1 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
